package es.uv.garcosda.endpoints;

import java.util.List;
import java.util.stream.Collectors;

import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.security.core.Authentication;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import es.uv.garcosda.models.AuthenticatedUser;

@RestController
@RequestMapping("/api/v1/users")
public class UserRestController {
	
	@GetMapping("authenticated")
	public ResponseEntity<AuthenticatedUser> getAuthenticatedUser(Authentication auth) {		
		if(auth.isAuthenticated()) {
			String username = auth.getName();
			List<String> roles = auth.getAuthorities()
									 .stream()
										 .map(authority -> authority.getAuthority())
									 	 .collect(Collectors.toList());
			AuthenticatedUser authenticatedUser = new AuthenticatedUser(username, roles);
			return new ResponseEntity<>(authenticatedUser,HttpStatus.OK);
		}
		return new ResponseEntity<>(HttpStatus.UNAUTHORIZED);
	}
	

	
	@GetMapping("roles/{username_}")
	@PreAuthorize("#username_ == authentication.principal.username")
	public ResponseEntity<AuthenticatedUser> getMyRoles(@PathVariable String username_, Authentication auth) {
		if(auth.isAuthenticated()) {
			String username = auth.getName();
			List<String> roles = auth.getAuthorities()
									 .stream()
										 .map(authority -> authority.getAuthority())
									 	 .collect(Collectors.toList());
			AuthenticatedUser authenticatedUser = new AuthenticatedUser(username, roles);
			return new ResponseEntity<>(authenticatedUser,HttpStatus.OK);
		}
		return new ResponseEntity<>(HttpStatus.UNAUTHORIZED);
	}
}
